@@ -1,4 +1,5 @@
 import collections
+import importlib.metadata
 import logging
 import pathlib
 import optparse
@@ -7,8 +8,8 @@ import sys
 
 from packaging.utils import canonicalize_name
 from pip._internal.commands.show import search_packages_info
-from pip._internal.utils.misc import get_installed_distributions
 from pip_check_reqs import common
+from pip_check_reqs.common import version_info
 
 log = logging.getLogger(__name__)
 
@@ -20,7 +21,11 @@ def find_extra_reqs(options, requirements_filename):
 
     # 2. find which packages provide which files
     installed_files = {}
-    all_pkgs = (pkg.project_name for pkg in get_installed_distributions())
+    all_pkgs = (
+        dist.metadata["Name"] for dist
+        in importlib.metadata.distributions()
+    )
+
     for package in search_packages_info(all_pkgs):
         if isinstance(package, dict):  # pragma: no cover
             package_name = package['name']
@@ -82,8 +87,6 @@ def find_extra_reqs(options, requirements_filename):
 
 
 def main():
-    from pip_check_reqs import __version__
-
     usage = 'usage: %prog [options] files or directories'
     parser = optparse.OptionParser(usage)
     parser.add_option("--requirements-file",
@@ -129,7 +132,7 @@ def main():
                       action="store_true",
                       default=False,
                       help="be *really* verbose")
-    parser.add_option("--version",
+    parser.add_option("-V", "--version",
                       dest="version",
                       action="store_true",
                       default=False,
@@ -138,7 +141,8 @@ def main():
     (options, args) = parser.parse_args()
 
     if options.version:
-        sys.exit(__version__)
+        print(version_info())
+        sys.exit(0)
 
     if not args:
         parser.error("no source files or directories specified")
@@ -160,7 +164,7 @@ def main():
     log.setLevel(level)
     common.log.setLevel(level)
 
-    log.info('using pip_check_reqs-%s from %s', __version__, __file__)
+    log.info(version_info())
 
     extras = find_extra_reqs(
         options=options,
